@@ -40,7 +40,11 @@ async def handle_incoming(data):
 
 async def start_client(address, filter_string):
 
-    await sio.connect(f"{address}")
+    try:
+        await sio.connect(f"{address}")
+    except socketio.exceptions.ConnectionError:
+        print(f"Unable to connect to the address {address}")
+        exit()
 
     _toori.init(
         filter_string,
